pub struct RelocationType<A: ArchitectureRelocationEncoding> {
pub kind: RelocationKind,
pub encoding: RelocationEncoding<A>,
}Expand description
RelocationType contains all information needed to describe how a relocation should be
performed by the runtime
Fields
kind: RelocationKindHow this relocation should be adapted if the buffer gets moved
encoding: RelocationEncoding<A>The way this relocation is to be encoded
Implementations
Sourceimpl<A: ArchitectureRelocationEncoding> RelocationType<A>
impl<A: ArchitectureRelocationEncoding> RelocationType<A>
Sourcepub fn from_size(kind: RelocationKind, size: RelocationSize) -> Self
pub fn from_size(kind: RelocationKind, size: RelocationSize) -> Self
manually create a RelocationType for a simple size-based relocation