[−][src]Struct dynasmrt::VecAssembler
An assembler that assembles into a Vec<u8>, while supporting labels. To support the different types of relocations
it requires a base address of the to be assembled code to be specified.
Implementations
impl<R: Relocation> VecAssembler<R>[src]
pub fn new(baseaddr: usize) -> VecAssembler<R>[src]
Creates a new VecAssembler, with the specified base address.
pub fn commit(&mut self) -> Result<(), DynasmError>[src]
Resolves any relocations emitted to the assembler before this point. If an impossible relocation was specified before this point, returns them here.
pub fn alter(&mut self) -> UncommittedModifier[src]
Use an UncommittedModifier to alter uncommitted code.
This does not allow the user to change labels/relocations.
pub fn finalize(self) -> Result<Vec<u8>, DynasmError>[src]
Finalizes the VecAssembler, returning the resulting Vec<u8> containing all assembled data.
this implicitly commits any relocations beforehand and returns an error if required.